@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import json
-import random
 import warnings
 from copy import deepcopy
 
@@ -30,6 +29,8 @@ from pymatgen.core.tensors import Tensor
 from pymatgen.core.units import FloatWithUnit
 from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
 
+TEST_DIR = f"{TEST_FILES_DIR}/analysis/elasticity"
+
 
 class TestElasticTensor(PymatgenTest):
     def setUp(self):
@@ -41,8 +42,8 @@ class TestElasticTensor(PymatgenTest):
             [0, 0, 0, 0, 26.35, 0],
             [0, 0, 0, 0, 0, 26.35],
         ]
-        mat = np.random.randn(6, 6)
-        mat = mat + np.transpose(mat)
+        mat = np.random.default_rng().standard_normal((6, 6))
+        mat += np.transpose(mat)
         self.rand_elastic_tensor = ElasticTensor.from_voigt(mat)
         self.ft = np.array(
             [
@@ -65,10 +66,10 @@ class TestElasticTensor(PymatgenTest):
         )
 
         self.elastic_tensor_1 = ElasticTensor(self.ft)
-        filepath = f"{TEST_FILES_DIR}/Sn_def_stress.json"
+        filepath = f"{TEST_DIR}/Sn_def_stress.json"
         with open(filepath) as file:
             self.def_stress_dict = json.load(file)
-        with open(f"{TEST_FILES_DIR}/test_toec_data.json") as file:
+        with open(f"{TEST_DIR}/test_toec_data.json") as file:
             self.toec_dict = json.load(file)
         self.structure = self.get_structure("Sn")
 
@@ -164,10 +165,14 @@ class TestElasticTensor(PymatgenTest):
         for attr_name in struct_prop_dict:
             if attr_name not in ([*prop_dict, "structure"]):
                 with pytest.raises(
-                    ValueError, match="Bulk or shear modulus is negative, property cannot be determined"
+                    ValueError,
+                    match="Bulk or shear modulus is negative, property cannot be determined",
                 ):
                     getattr(test_et, attr_name)(struct)
-        with pytest.raises(ValueError, match="Bulk or shear modulus is negative, property cannot be determined"):
+        with pytest.raises(
+            ValueError,
+            match="Bulk or shear modulus is negative, property cannot be determined",
+        ):
             test_et.get_structure_property_dict(struct)
         noval_sprop_dict = test_et.get_structure_property_dict(struct, ignore_errors=True)
         assert noval_sprop_dict["snyder_ac"] is None
@@ -177,10 +182,14 @@ class TestElasticTensor(PymatgenTest):
         non_symm = self.ft
         non_symm[0, 1, 2, 2] += 1.0
         with pytest.warns(
-            UserWarning, match="Input elastic tensor does not satisfy standard Voigt symmetries"
+            UserWarning,
+            match="Input elastic tensor does not satisfy standard Voigt symmetries",
         ) as warns:
             ElasticTensor(non_symm)
-        assert len(warns) == 1
+        assert (
+            sum("Input elastic tensor does not satisfy standard Voigt symmetries" in str(warn) for warn in warns) == 1
+        )
+
         bad_tensor1 = np.zeros((3, 3, 3))
         bad_tensor2 = np.zeros((3, 3, 3, 2))
         with pytest.raises(ValueError, match="ElasticTensor input must be rank 4"):
@@ -193,13 +202,13 @@ class TestElasticTensor(PymatgenTest):
 
     def test_from_pseudoinverse(self):
         strain_list = [Strain.from_deformation(def_matrix) for def_matrix in self.def_stress_dict["deformations"]]
-        stress_list = list(self.def_stress_dict["stresses"])
+        stresses = list(self.def_stress_dict["stresses"])
         with pytest.warns(
             UserWarning,
             match="Pseudo-inverse fitting of Strain/Stress lists may yield questionable results from "
             "vasp data, use with caution",
         ):
-            et_fl = -0.1 * ElasticTensor.from_pseudoinverse(strain_list, stress_list).voigt
+            et_fl = -0.1 * ElasticTensor.from_pseudoinverse(strain_list, stresses).voigt
             assert_allclose(
                 et_fl.round(2),
                 [
@@ -217,7 +226,8 @@ class TestElasticTensor(PymatgenTest):
         stresses = self.toec_dict["stresses"]
         with pytest.warns(UserWarning, match="No eq state found, returning zero voigt stress") as warns:
             et = ElasticTensor.from_independent_strains(strains, stresses)
-        assert len(warns) == 2
+        assert sum("No eq state found" in str(warn) for warn in warns) == 1
+        assert sum("Extra strain states in strain-" in str(warn) for warn in warns) == 1
         assert_allclose(et.voigt, self.toec_dict["C2_raw"], atol=1e1)
 
     def test_energy_density(self):
@@ -255,7 +265,7 @@ class TestElasticTensor(PymatgenTest):
 
 class TestElasticTensorExpansion(PymatgenTest):
     def setUp(self):
-        with open(f"{TEST_FILES_DIR}/test_toec_data.json") as file:
+        with open(f"{TEST_DIR}/test_toec_data.json") as file:
             self.data_dict = json.load(file)
         self.strains = [Strain(sm) for sm in self.data_dict["strains"]]
         self.pk_stresses = [Stress(d) for d in self.data_dict["pk_stresses"]]
@@ -294,7 +304,7 @@ class TestElasticTensorExpansion(PymatgenTest):
     def test_gruneisen(self):
         # Get GGT
         ggt = self.exp_cu.get_ggt([1, 0, 0], [0, 1, 0])
-        assert_allclose(np.eye(3) * np.array([4.92080537, 4.2852349, -0.7147651]), ggt)
+        assert_allclose(ggt, np.eye(3) * np.array([4.92080537, 4.2852349, -0.7147651]))
         # Get TGT
         tgt = self.exp_cu.get_tgt()
         assert_allclose(tgt, np.eye(3) * 2.59631832, atol=1e-12)
@@ -334,11 +344,11 @@ class TestElasticTensorExpansion(PymatgenTest):
         # Ensure zero strain is same as SOEC
         test_zero = self.exp_cu.get_effective_ecs(np.zeros((3, 3)))
         assert_allclose(test_zero, self.exp_cu[0])
-        s = np.zeros((3, 3))
-        s[0, 0] = 0.02
-        test_2percent = self.exp_cu.get_effective_ecs(s)
+        strain = np.zeros((3, 3))
+        strain[0, 0] = 0.02
+        test_2percent = self.exp_cu.get_effective_ecs(strain)
         diff = test_2percent - test_zero
-        assert_allclose(self.exp_cu[1].einsum_sequence([s]), diff)
+        assert_allclose(self.exp_cu[1].einsum_sequence([strain]), diff)
 
     def test_get_strain_from_stress(self):
         strain = Strain.from_voigt([0.05, 0, 0, 0, 0, 0])
@@ -356,7 +366,7 @@ class TestElasticTensorExpansion(PymatgenTest):
 
 class TestNthOrderElasticTensor(PymatgenTest):
     def setUp(self):
-        with open(f"{TEST_FILES_DIR}/test_toec_data.json") as file:
+        with open(f"{TEST_DIR}/test_toec_data.json") as file:
             self.data_dict = json.load(file)
         self.strains = [Strain(sm) for sm in self.data_dict["strains"]]
         self.pk_stresses = [Stress(d) for d in self.data_dict["pk_stresses"]]
@@ -392,10 +402,10 @@ class TestNthOrderElasticTensor(PymatgenTest):
 
 
 class TestDiffFit(PymatgenTest):
-    """Tests various functions related to diff fitting."""
+    """Test various functions related to diff fitting."""
 
     def setUp(self):
-        with open(f"{TEST_FILES_DIR}/test_toec_data.json") as file:
+        with open(f"{TEST_DIR}/test_toec_data.json") as file:
             self.data_dict = json.load(file)
         self.strains = [Strain(sm) for sm in self.data_dict["strains"]]
         self.pk_stresses = [Stress(d) for d in self.data_dict["pk_stresses"]]
@@ -404,19 +414,20 @@ class TestDiffFit(PymatgenTest):
         strain_inds = [(0,), (1,), (2,), (1, 3), (1, 2, 3)]
         vecs = {}
         strain_states = []
+        rng = np.random.default_rng()
         for strain_ind in strain_inds:
             ss = np.zeros(6)
             np.put(ss, strain_ind, 1)
             strain_states.append(tuple(ss))
             vec = np.zeros((4, 6))
-            rand_values = np.random.uniform(0.1, 1, 4)
-            for i in strain_ind:
-                vec[:, i] = rand_values
+            rand_values = rng.uniform(0.1, 1, 4)
+            for idx in strain_ind:
+                vec[:, idx] = rand_values
             vecs[strain_ind] = vec
         all_strains = [Strain.from_voigt(v).zeroed() for vec in vecs.values() for v in vec]
-        random.shuffle(all_strains)
-        all_stresses = [Stress.from_voigt(np.random.random(6)).zeroed() for s in all_strains]
-        strain_dict = {k.tobytes(): v for k, v in zip(all_strains, all_stresses)}
+        rng.shuffle(all_strains)
+        all_stresses = [Stress.from_voigt(rng.random(6)).zeroed() for _ in all_strains]
+        strain_dict = {k.tobytes(): v for k, v in zip(all_strains, all_stresses, strict=True)}
         ss_dict = get_strain_state_dict(all_strains, all_stresses, add_eq=False)
         # Check length of ss_dict
         assert len(strain_inds) == len(ss_dict)
@@ -424,7 +435,7 @@ class TestDiffFit(PymatgenTest):
         assert set(strain_states) == set(ss_dict)
         for data in ss_dict.values():
             # Check correspondence of strains/stresses
-            for strain, stress in zip(data["strains"], data["stresses"]):
+            for strain, stress in zip(data["strains"], data["stresses"], strict=True):
                 assert_allclose(
                     Stress.from_voigt(stress),
                     strain_dict[Strain.from_voigt(strain).tobytes()],
@@ -466,9 +477,13 @@ class TestDiffFit(PymatgenTest):
 
     def test_fit(self):
         diff_fit(self.strains, self.pk_stresses, self.data_dict["eq_stress"])
-        reduced = [(e, pk) for e, pk in zip(self.strains, self.pk_stresses) if not (abs(abs(e) - 0.05) < 1e-10).any()]
+        reduced = [
+            (e, pk)
+            for e, pk in zip(self.strains, self.pk_stresses, strict=True)
+            if not (abs(abs(e) - 0.05) < 1e-10).any()
+        ]
         # Get reduced dataset
-        r_strains, r_pk_stresses = zip(*reduced)
+        r_strains, r_pk_stresses = zip(*reduced, strict=True)
         c2 = diff_fit(r_strains, r_pk_stresses, self.data_dict["eq_stress"], order=2)
         c2, c3, _c4 = diff_fit(r_strains, r_pk_stresses, self.data_dict["eq_stress"], order=4)
         c2, c3 = diff_fit(self.strains, self.pk_stresses, self.data_dict["eq_stress"], order=3)
