@@ -3,12 +3,12 @@
 from __future__ import annotations
 
 import pickle
+import platform
 
 import numpy as np
 import pytest
 from numpy.testing import assert_allclose
 
-import pymatgen
 from pymatgen.analysis.piezo_sensitivity import (
     BornEffectiveCharge,
     ForceConstantMatrix,
@@ -16,6 +16,7 @@ from pymatgen.analysis.piezo_sensitivity import (
     get_piezo,
     rand_piezo,
 )
+from pymatgen.io.phonopy import get_phonopy_structure
 from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
 
 try:
@@ -43,9 +44,9 @@ class TestPiezoSensitivity(PymatgenTest):
         self.shared_ops = np.load(f"{TEST_DIR}/sharedops.npy", allow_pickle=True)
         self.IST_operations = np.load(f"{TEST_DIR}/istops.npy", allow_pickle=True)
         with open(f"{TEST_DIR}/becops.pkl", "rb") as file:
-            self.BEC_operations = pickle.load(file)
+            self.BEC_operations = pickle.load(file)  # noqa: S301
         with open(f"{TEST_DIR}/fcmops.pkl", "rb") as file:
-            self.FCM_operations = pickle.load(file)
+            self.FCM_operations = pickle.load(file)  # noqa: S301
         self.piezo = np.array(
             [
                 [
@@ -137,7 +138,7 @@ class TestPiezoSensitivity(PymatgenTest):
         fcm = ForceConstantMatrix(self.piezo_struct, self.FCM, self.point_ops, self.shared_ops)
         fcm.get_FCM_operations()
 
-        fcm = fcm.get_symmetrized_FCM(np.random.rand(30, 30))
+        fcm = fcm.get_symmetrized_FCM(np.random.default_rng().random((30, 30)))
         fcm = np.reshape(fcm, (10, 3, 10, 3)).swapaxes(1, 2)
         for i in range(len(self.FCM_operations)):
             for j in range(len(self.FCM_operations[i][4])):
@@ -207,12 +208,16 @@ class TestPiezoSensitivity(PymatgenTest):
             assert_allclose(asum1, np.zeros([3, 3]), atol=1e-5)
             assert_allclose(asum2, np.zeros([3, 3]), atol=1e-5)
 
+    @pytest.mark.skipif(
+        platform.system() == "Windows" and int(np.__version__[0]) >= 2,
+        reason="See https://github.com/conda-forge/phonopy-feedstock/pull/158#issuecomment-2227506701",
+    )
     def test_rand_fcm(self):
         pytest.importorskip("phonopy")
         fcm = ForceConstantMatrix(self.piezo_struct, self.FCM, self.point_ops, self.shared_ops)
         fcm.get_FCM_operations()
         rand_FCM = fcm.get_rand_FCM()
-        structure = pymatgen.io.phonopy.get_phonopy_structure(self.piezo_struct)
+        structure = get_phonopy_structure(self.piezo_struct)
         pn_struct = Phonopy(structure, np.eye(3), np.eye(3))
 
         pn_struct.set_force_constants(rand_FCM)
@@ -257,10 +262,19 @@ class TestPiezoSensitivity(PymatgenTest):
         piezo = get_piezo(self.BEC, self.IST, self.FCM)
         assert_allclose(piezo, self.piezo, atol=1e-5)
 
+    @pytest.mark.skipif(
+        platform.system() == "Windows" and int(np.__version__[0]) >= 2,
+        reason="See https://github.com/conda-forge/phonopy-feedstock/pull/158#issuecomment-2227506701",
+    )
     def test_rand_piezo(self):
         pytest.importorskip("phonopy")
         rand_BEC, rand_IST, rand_FCM, _piezo = rand_piezo(
-            self.piezo_struct, self.point_ops, self.shared_ops, self.BEC, self.IST, self.FCM
+            self.piezo_struct,
+            self.point_ops,
+            self.shared_ops,
+            self.BEC,
+            self.IST,
+            self.FCM,
         )
 
         for ii in range(len(self.BEC_operations)):
@@ -279,7 +293,7 @@ class TestPiezoSensitivity(PymatgenTest):
                     atol=1e-3,
                 )
 
-        structure = pymatgen.io.phonopy.get_phonopy_structure(self.piezo_struct)
+        structure = get_phonopy_structure(self.piezo_struct)
         pn_struct = Phonopy(structure, np.eye(3), np.eye(3))
 
         pn_struct.set_force_constants(rand_FCM)
