@@ -75,8 +75,8 @@ class TestElement(PymatgenTest):
                 (2, "p", 6),
                 (3, "s", 2),
                 (3, "p", 6),
-                (3, "d", 6),
                 (4, "s", 2),
+                (3, "d", 6),
             ],
             "Li": [(1, "s", 2), (2, "s", 1)],
             "U": [
@@ -85,19 +85,19 @@ class TestElement(PymatgenTest):
                 (2, "p", 6),
                 (3, "s", 2),
                 (3, "p", 6),
-                (3, "d", 10),
                 (4, "s", 2),
+                (3, "d", 10),
                 (4, "p", 6),
-                (4, "d", 10),
                 (5, "s", 2),
+                (4, "d", 10),
                 (5, "p", 6),
+                (6, "s", 2),
                 (4, "f", 14),
                 (5, "d", 10),
-                (6, "s", 2),
                 (6, "p", 6),
+                (7, "s", 2),
                 (5, "f", 3),
                 (6, "d", 1),
-                (7, "s", 2),
             ],
         }
         for k, v in cases.items():
@@ -170,6 +170,11 @@ class TestElement(PymatgenTest):
         for k, v in cases.items():
             assert ElementBase.from_row_and_group(v[0], v[1]) == Element(k)
 
+    def test_n_electrons(self):
+        cases = {"O": 8, "Fe": 26, "Li": 3, "Be": 4}
+        for k, v in cases.items():
+            assert Element(k).n_electrons == v
+
     def test_valence(self):
         cases = {"O": (1, 4), "Fe": (2, 6), "Li": (0, 1), "Be": (0, 2)}
         for k, v in cases.items():
@@ -361,10 +366,11 @@ class TestElement(PymatgenTest):
 
     def test_pickle(self):
         pickled = pickle.dumps(Element.Fe)
-        assert Element.Fe == pickle.loads(pickled)
+        assert Element.Fe == pickle.loads(pickled)  # noqa: S301
 
         # Test 5 random elements
-        for idx in np.random.randint(1, 104, size=5):
+        rng = np.random.default_rng()
+        for idx in rng.integers(1, 104, size=5):
             self.serialize_with_pickle(Element.from_Z(idx))
 
     def test_print_periodic_table(self):
@@ -379,7 +385,11 @@ class TestElement(PymatgenTest):
         assert list(map(str, elems)) == ["H", "H", "H"]
         assert [el.A for el in elems] == [1, 2, 3]
         assert all(abs(el.atomic_mass - idx - 1) < 0.1 for idx, el in enumerate(elems))
-        assert [el.atomic_mass for el in elems] == [1.00794, 2.013553212712, 3.0155007134]
+        assert [el.atomic_mass for el in elems] == [
+            1.00794,
+            2.013553212712,
+            3.0155007134,
+        ]
 
 
 class TestSpecies(PymatgenTest):
@@ -423,7 +433,7 @@ class TestSpecies(PymatgenTest):
         assert elem_list == deepcopy(elem_list), "Deepcopy operation doesn't produce exact copy."
 
     def test_pickle(self):
-        assert self.specie1 == pickle.loads(pickle.dumps(self.specie1))
+        assert self.specie1 == pickle.loads(pickle.dumps(self.specie1))  # noqa: S301
         for idx in range(1, 5):
             self.serialize_with_pickle(getattr(self, f"specie{idx}"))
         cs = Species("Cs1+")
@@ -433,7 +443,7 @@ class TestSpecies(PymatgenTest):
             pickle.dump((cs, cl), file)
 
         with open(f"{self.tmp_path}/cscl.pickle", "rb") as file:
-            tup = pickle.load(file)
+            tup = pickle.load(file)  # noqa: S301
             assert tup == (cs, cl)
 
     def test_get_crystal_field_spin(self):
@@ -584,7 +594,7 @@ class TestDummySpecies:
     def test_pickle(self):
         el1 = DummySpecies("X", 3)
         pickled = pickle.dumps(el1)
-        assert el1 == pickle.loads(pickled)
+        assert el1 == pickle.loads(pickled)  # noqa: S301
 
     def test_sort(self):
         Fe, X = Element.Fe, DummySpecies("X")
@@ -601,13 +611,95 @@ class TestDummySpecies:
         )
         assert sp.spin == 5
 
-    def test_not_implemented(self):
-        with pytest.raises(NotImplementedError):
-            _ = Species("Fe", 2).full_electronic_structure
-        with pytest.raises(NotImplementedError):
-            _ = Species("Fe", 2).electronic_structure
-        with pytest.raises(NotImplementedError):
-            _ = Species("Fe", 2).valence
+    def test_species_electronic_structure(self):
+        assert Species("Fe", 0).electronic_structure == "[Ar].3d6.4s2"
+        assert Species("Fe", 0).n_electrons == 26
+        assert Species("Fe", 0).full_electronic_structure == [
+            (1, "s", 2),
+            (2, "s", 2),
+            (2, "p", 6),
+            (3, "s", 2),
+            (3, "p", 6),
+            (4, "s", 2),
+            (3, "d", 6),
+        ]
+        assert Species("Fe", 0).valence == (2, 6)
+
+        assert Species("Fe", 2).electronic_structure == "[Ar].3d6"
+        assert Species("Fe", 2).n_electrons == 24
+        assert Species("Fe", 2).full_electronic_structure == [
+            (1, "s", 2),
+            (2, "s", 2),
+            (2, "p", 6),
+            (3, "s", 2),
+            (3, "p", 6),
+            (3, "d", 6),
+        ]
+        assert Species("Fe", 2).valence == (2, 6)
+
+        assert Species("Fe", 3).electronic_structure == "[Ar].3d5"
+        assert Species("Fe", 3).n_electrons == 23
+        assert Species("Fe", 3).full_electronic_structure == [
+            (1, "s", 2),
+            (2, "s", 2),
+            (2, "p", 6),
+            (3, "s", 2),
+            (3, "p", 6),
+            (3, "d", 5),
+        ]
+        assert Species("Fe", 3).valence == (2, 5)
+
+        assert Species("Th", 4).electronic_structure == "[Hg].6p6"
+        assert Species("Th", 4).full_electronic_structure == [
+            (1, "s", 2),
+            (2, "s", 2),
+            (2, "p", 6),
+            (3, "s", 2),
+            (3, "p", 6),
+            (4, "s", 2),
+            (3, "d", 10),
+            (4, "p", 6),
+            (5, "s", 2),
+            (4, "d", 10),
+            (5, "p", 6),
+            (6, "s", 2),
+            (4, "f", 14),
+            (5, "d", 10),
+            (6, "p", 6),
+        ]
+        assert Species("Th", 4).valence == (1, 6)
+
+        assert Species("Li", 1).electronic_structure == "1s2"
+        assert Species("Li", 1).n_electrons == 2
+        # alkali metals, all p
+        for el in ["Na", "K", "Rb", "Cs"]:
+            assert Species(el, 1).electronic_structure.split(".")[-1][1::] == "p6", f"Failure for {el} +1"
+        for el in ["Ca", "Mg", "Ba", "Sr"]:
+            assert Species(el, 2).electronic_structure.split(".")[-1][1::] == "p6", f"Failure for {el} +2"
+        # valence shell should be f (l=3) for all lanthanide ions except La+3 and Lu+3
+        for el in [
+            "Ce",
+            "Nd",
+            "Sm",
+            "Eu",
+            "Gd",
+            "Tb",
+            "Dy",
+            "Ho",
+            "Er",
+            "Tm",
+            "Yb",
+            "Lu",
+        ]:
+            assert Species(el, 3).valence[0] == 3, f"Failure for {el} +3"
+
+        for el in Element:
+            for ox in el.common_oxidation_states:
+                if str(el) == "H" and ox == 1:
+                    continue
+                n_electron_el = sum(orb[-1] for orb in el.full_electronic_structure)
+                n_electron_sp = sum(orb[-1] for orb in Species(el, ox).full_electronic_structure)
+                assert n_electron_el - n_electron_sp == ox, f"Failure for {el} {ox}"
 
 
 def test_get_el_sp():
