@@ -41,7 +41,11 @@ def test_energy_adjustment():
 def test_energy_adjustment_repr():
     comp_cls = MaterialsProject2020Compatibility()
     cls_name = type(comp_cls).__name__
-    for cls, label in ((None, "unknown"), (comp_cls, cls_name), ({"@class": cls_name}, cls_name)):
+    for cls, label in (
+        (None, "unknown"),
+        (comp_cls, cls_name),
+        ({"@class": cls_name}, cls_name),
+    ):
         ea = EnergyAdjustment(10, cls=cls)
         assert (
             repr(ea) == "EnergyAdjustment(name='Manual adjustment', value=10.0, uncertainty=nan, description='', "
@@ -238,6 +242,19 @@ class TestComputedEntry(TestCase):
             assert entry == copy
             assert str(entry) == str(copy)
 
+    def test_from_dict_null_fields(self):
+        ce_dict = self.entry.as_dict()
+        for k in (
+            "energy_adjustments",
+            "parameters",
+            "data",
+        ):
+            ce = ce_dict.copy()
+            ce[k] = None
+            new_ce = ComputedEntry.from_dict(ce)
+            assert new_ce == self.entry
+            assert getattr(new_ce, k, None) is not None
+
 
 class TestComputedStructureEntry(TestCase):
     def setUp(self):
