@@ -185,8 +185,8 @@ class TestMultiDataset(PymatgenTest):
         assert len(multi) == 1
         assert multi.ndtset == 1
         assert multi.isnc
-        for i, inp in enumerate(multi):
-            assert list(inp) == list(multi[i])
+        for inp in multi:
+            assert list(inp) == list(inp)
 
         multi.addnew_from(0)
         assert multi.ndtset == 2
@@ -235,7 +235,7 @@ class TestMultiDataset(PymatgenTest):
         assert new_multi.ndtset == multi.ndtset
         assert new_multi.structure == multi.structure
 
-        for old_inp, new_inp in zip(multi, new_multi):
+        for old_inp, new_inp in zip(multi, new_multi, strict=True):
             assert old_inp is not new_inp
             assert old_inp.as_dict() == new_inp.as_dict()
 
