@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import hashlib
 import os
+import unittest
 from glob import glob
 from zipfile import ZipFile
 
@@ -10,7 +11,7 @@ import pytest
 from monty.json import MontyDecoder
 from monty.serialization import loadfn
 from numpy.testing import assert_allclose
-from pytest import MonkeyPatch, approx, mark
+from pytest import approx
 
 from pymatgen.analysis.structure_matcher import StructureMatcher
 from pymatgen.core import SETTINGS, Lattice, Species, Structure
@@ -58,10 +59,10 @@ from pymatgen.util.testing import FAKE_POTCAR_DIR, TEST_FILES_DIR, VASP_IN_DIR,
 
 TEST_DIR = f"{TEST_FILES_DIR}/io/vasp"
 
-MonkeyPatch().setitem(SETTINGS, "PMG_VASP_PSP_DIR", str(FAKE_POTCAR_DIR))
+pytest.MonkeyPatch().setitem(SETTINGS, "PMG_VASP_PSP_DIR", str(FAKE_POTCAR_DIR))
 
 NO_PSP_DIR = SETTINGS.get("PMG_VASP_PSP_DIR") is None
-skip_if_no_psp_dir = mark.skipif(NO_PSP_DIR, reason="PMG_VASP_PSP_DIR is not set")
+skip_if_no_psp_dir = pytest.mark.skipif(NO_PSP_DIR, reason="PMG_VASP_PSP_DIR is not set")
 
 dummy_structure = Structure(
     [1, 0, 0, 0, 1, 0, 0, 0, 1],
@@ -107,25 +108,25 @@ class TestSetChangeCheck(PymatgenTest):
             with open(input_set) as file:
                 text = file.read().encode("utf-8")
                 name = os.path.basename(input_set)
-                hashes[name] = hashlib.sha1(text).hexdigest()
+                hashes[name] = hashlib.sha256(text).hexdigest()
 
         known_hashes = {
-            "MatPESStaticSet.yaml": "8edecff2bbd1932c53159f56a8e6340e900aaa2f",
-            "MITRelaxSet.yaml": "1a0970f8cad9417ec810f7ab349dc854eaa67010",
-            "MPAbsorptionSet.yaml": "5931e1cb3cf8ba809b3d4f4a5960d728c682adf1",
-            "MPHSERelaxSet.yaml": "0d0d96a620461071cfd416ec9d5d6a8d2dfd0855",
-            "MPRelaxSet.yaml": "f2949cdc5dc8cd0bee6d39a5df0d6a6b7c144821",
-            "MPSCANRelaxSet.yaml": "167668225129002b49dc3550c04659869b9b9e47",
-            "MVLGWSet.yaml": "104ae93c3b3be19a13b0ee46ebdd0f40ceb96597",
-            "MVLRelax52Set.yaml": "4cfc6b1bd0548e45da3bde4a9c65b3249da13ecd",
-            "PBE54Base.yaml": "ec317781a7f344beb54c17a228db790c0eb49282",
-            "PBE64Base.yaml": "480c41c2448cb25706181de268090618e282b264",
-            "VASPIncarBase.yaml": "19762515f8deefb970f2968fca48a0d67f7964d4",
-            "vdW_parameters.yaml": "04bb09bb563d159565bcceac6a11e8bdf0152b79",
+            "MVLGWSet.yaml": "eba4564a18b99494a08ab6fdbe5364e7212b5992c7a9ef109001ce314a5b33db",
+            "MVLRelax52Set.yaml": "3660879566a9ee2ab289e81d7916335b2f33ab24dcb3c16ba7aaca9ff22dfbad",
+            "MPHSERelaxSet.yaml": "1779cb6a6af43ad54a12aec22882b9b8aa3469b764e29ac4ab486960d067b811",
+            "VASPIncarBase.yaml": "8c1ce90d6697e45b650e1881e2b3d82a733dba17fb1bd73747a38261ec65a4c4",
+            "MPSCANRelaxSet.yaml": "ad652ea740d06f9edd979494f31e25074b82b9fffdaaf7eff2ae5541fb0e6288",
+            "PBE64Base.yaml": "3434c918c17706feae397d0852f2224e771db94d7e4c988039e8658e66d87494",
+            "MPRelaxSet.yaml": "c9b0a519588fb3709509a9f9964632692584905e2961a0fe2e5f657561913083",
+            "MITRelaxSet.yaml": "0b4bec619fa860dac648584853c3b3d5407e4148a85d0e95024fbd1dc315669d",
+            "vdW_parameters.yaml": "7d2599a855533865335a313c043b6f89e03fc2633c88b6bc721723d94cc862bd",
+            "MatPESStaticSet.yaml": "4ec60ad4bbbb9a756f1b3fea8ca4eab8fc767d8f6a67332e7af3908c910fd7c5",
+            "MPAbsorptionSet.yaml": "e49cd0ab87864f1c244e9b5ceb4703243116ec1fbb8958a374ddff07f7a5625c",
+            "PBE54Base.yaml": "cdffe123eca8b19354554b60a7f8de9b8776caac9e1da2bd2a0516b7bfac8634",
         }
 
-        for input_set in hashes:
-            assert hashes[input_set] == known_hashes[input_set], f"{input_set=}\n{msg}"
+        for input_set, hash_str in hashes.items():
+            assert hash_str == known_hashes[input_set], f"{input_set=}\n{msg}"
 
 
 class TestVaspInputSet(PymatgenTest):
@@ -170,17 +171,28 @@ class TestMITMPRelaxSet(PymatgenTest):
     def setUpClass(cls):
         cls.set = MITRelaxSet
         cls.mp_set = MPRelaxSet
-        cls.monkeypatch = MonkeyPatch()
 
         filepath = f"{VASP_IN_DIR}/POSCAR"
         cls.structure = Structure.from_file(filepath)
         cls.coords = [[0, 0, 0], [0.75, 0.5, 0.75]]
-        cls.lattice = Lattice([[3.8401979337, 0, 0], [1.9200989668, 3.3257101909, 0], [0, -2.2171384943, 3.1355090603]])
+        cls.lattice = Lattice(
+            [
+                [3.8401979337, 0, 0],
+                [1.9200989668, 3.3257101909, 0],
+                [0, -2.2171384943, 3.1355090603],
+            ]
+        )
 
         cls.mit_set = cls.set(cls.structure)
         cls.mit_set_unsorted = cls.set(cls.structure, sort_structure=False)
         cls.mp_set = MPRelaxSet(cls.structure)
 
+    def test_pbe64(self):
+        vis = MPRelaxSet(self.structure, user_potcar_functional="PBE_64")
+        assert vis.potcar[0].keywords["TITEL"] == "PAW_PBE Fe_pv 02Aug2007"
+        assert vis.potcar[1].keywords["TITEL"] == "PAW_PBE P 06Sep2000"
+        assert vis.potcar[2].keywords["TITEL"] == "PAW_PBE O 08Apr2002"
+
     def test_no_structure_init(self):
         # basic test of initialization with no structure.
         vis = MPRelaxSet()
@@ -243,7 +255,13 @@ class TestMITMPRelaxSet(PymatgenTest):
 
     def test_potcar_symbols(self):
         coords = [[0, 0, 0], [0.75, 0.5, 0.75], [0.75, 0.25, 0.75]]
-        lattice = Lattice([[3.8401979337, 0, 0], [1.9200989668, 3.3257101909, 0], [0, -2.2171384943, 3.1355090603]])
+        lattice = Lattice(
+            [
+                [3.8401979337, 0, 0],
+                [1.9200989668, 3.3257101909, 0],
+                [0, -2.2171384943, 3.1355090603],
+            ]
+        )
         structure = Structure(lattice, ["P", "Fe", "O"], coords)
         mit_param_set = self.set(structure)
         syms = mit_param_set.potcar_symbols
@@ -256,8 +274,8 @@ class TestMITMPRelaxSet(PymatgenTest):
         structure = Structure(self.lattice, ["P", "Fe"], self.coords)
         # Use pytest's monkeypatch to temporarily point pymatgen to a directory
         # containing the wrong POTCARs (LDA potcars in a PBE directory)
-        with self.monkeypatch.context() as m:
-            m.setitem(SETTINGS, "PMG_VASP_PSP_DIR", str(f"{VASP_IN_DIR}/wrong_potcars"))
+        with pytest.MonkeyPatch().context() as monkeypatch:
+            monkeypatch.setitem(SETTINGS, "PMG_VASP_PSP_DIR", str(f"{VASP_IN_DIR}/wrong_potcars"))
             with pytest.warns(BadInputSetWarning, match="not known by pymatgen"):
                 _ = self.set(structure).potcar
 
@@ -265,9 +283,15 @@ class TestMITMPRelaxSet(PymatgenTest):
         # https://github.com/materialsproject/pymatgen/pull/3022
         for user_potcar_settings in [{"Fe": "Fe_pv"}, {"W": "W_pv"}, None]:
             for species in [("W", "W"), ("Fe", "W"), ("Fe", "Fe")]:
-                struct = Structure(lattice=Lattice.cubic(3), species=species, coords=[[0, 0, 0], [0.5, 0.5, 0.5]])
+                struct = Structure(
+                    lattice=Lattice.cubic(3),
+                    species=species,
+                    coords=[[0, 0, 0], [0.5, 0.5, 0.5]],
+                )
                 relax_set = MPRelaxSet(
-                    structure=struct, user_potcar_functional="PBE_54", user_potcar_settings=user_potcar_settings
+                    structure=struct,
+                    user_potcar_functional="PBE_54",
+                    user_potcar_settings=user_potcar_settings,
                 )
                 expected = {  # noqa: SIM222
                     **({"W": "W_sv"} if "W" in struct.symbol_set else {}),
@@ -297,7 +321,8 @@ class TestMITMPRelaxSet(PymatgenTest):
         # disordered structure are not supported
         disordered = Structure.from_spacegroup("Im-3m", Lattice.cubic(3), [Composition("Fe0.5Mn0.5")], [[0, 0, 0]])
         with pytest.raises(
-            ValueError, match="Disordered structure with partial occupancies cannot be converted into POSCAR"
+            ValueError,
+            match="Disordered structure with partial occupancies cannot be converted into POSCAR",
         ):
             _ = self.set(disordered).nelect
 
@@ -343,13 +368,21 @@ class TestMITMPRelaxSet(PymatgenTest):
         coords.extend((np.array([0, 0, 0]), np.array([0.75, 0.5, 0.75])))
 
         # Silicon structure for testing.
-        lattice = [[3.8401979337, 0.00, 0.00], [1.9200989668, 3.3257101909, 0.00], [0.00, -2.2171384943, 3.1355090603]]
+        lattice = [
+            [3.8401979337, 0.00, 0.00],
+            [1.9200989668, 3.3257101909, 0.00],
+            [0.00, -2.2171384943, 3.1355090603],
+        ]
         struct = Structure(lattice, [si, si], coords)
         incar = MPRelaxSet(struct).incar
         assert "LDAU" not in incar
 
         coords = [[0, 0, 0], [0.75, 0.5, 0.75]]
-        lattice = [[3.8401979337, 0.00, 0.00], [1.9200989668, 3.3257101909, 0.00], [0.00, -2.2171384943, 3.1355090603]]
+        lattice = [
+            [3.8401979337, 0.00, 0.00],
+            [1.9200989668, 3.3257101909, 0.00],
+            [0.00, -2.2171384943, 3.1355090603],
+        ]
         struct = Structure(lattice, ["Fe", "Mn"], coords)
 
         incar = MPRelaxSet(struct).incar
@@ -433,7 +466,11 @@ class TestMITMPRelaxSet(PymatgenTest):
         struct = Structure(lattice, ["Fe", "Cl", "S"], coords)
         incar = self.set(
             struct,
-            user_incar_settings={"LDAU": True, "LDAUL": {"Fe": 3}, "LDAUU": {"Fe": 1.8}},
+            user_incar_settings={
+                "LDAU": True,
+                "LDAUL": {"Fe": 3},
+                "LDAUU": {"Fe": 1.8},
+            },
         ).incar
         assert incar["LDAUL"] == [3.0, 0, 0]
         assert incar["LDAUU"] == [1.8, 0, 0]
@@ -458,7 +495,11 @@ class TestMITMPRelaxSet(PymatgenTest):
         coords.append(np.array([0.75, 0.5, 0.75]))
 
         # Silicon structure for testing.
-        lattice = [[3.8401979337, 0.00, 0.00], [1.9200989668, 3.3257101909, 0.00], [0.00, -2.2171384943, 3.1355090603]]
+        lattice = [
+            [3.8401979337, 0.00, 0.00],
+            [1.9200989668, 3.3257101909, 0.00],
+            [0.00, -2.2171384943, 3.1355090603],
+        ]
         struct = Structure(lattice, [si, si], coords, charge=1)
         mpr = MPRelaxSet(struct, use_structure_charge=True)
         assert mpr.incar["NELECT"] == 7, "NELECT not properly set for nonzero charge"
@@ -592,7 +633,12 @@ class TestMITMPRelaxSet(PymatgenTest):
     @skip_if_no_psp_dir
     def test_write_input_potcar_spec(self):
         self.mit_set.write_input(self.tmp_path, potcar_spec=True)
-        assert {*os.listdir(self.tmp_path)} == {"INCAR", "KPOINTS", "POSCAR", "POTCAR.spec"}
+        assert {*os.listdir(self.tmp_path)} == {
+            "INCAR",
+            "KPOINTS",
+            "POSCAR",
+            "POTCAR.spec",
+        }
 
     @skip_if_no_psp_dir
     def test_user_potcar_settings(self):
@@ -730,12 +776,12 @@ class TestMPStaticSet(PymatgenTest):
             vis = self.set(vis.structure, user_incar_settings={"LUSE_VDW": True, "LASPH": False})
             vis.incar.items()
         with pytest.warns(BadInputSetWarning, match=r"LASPH"):
-            dummy_struc = Structure(
+            dummy_struct = Structure(
                 lattice=[[0, 2, 2], [2, 0, 2], [2, 2, 0]],
                 species=["Fe", "O"],
                 coords=[[0, 0, 0], [0.5, 0.5, 0.5]],
             )
-            vis = self.set(dummy_struc, user_incar_settings={"LDAU": True, "LASPH": False})
+            vis = self.set(dummy_struct, user_incar_settings={"LDAU": True, "LASPH": False})
             vis.incar.items()
 
     def test_user_incar_kspacing(self):
@@ -811,11 +857,17 @@ class TestMPStaticSet(PymatgenTest):
         assert static_set.calculate_ng() == ([30, 48, 50], [60, 96, 100])
         # test `custom_encut` kwarg for final structure in above test using
         # an (obviously fictitious) custom encut.
-        assert static_set.calculate_ng(custom_encut=2000) == ([56, 96, 96], [112, 192, 192])
+        assert static_set.calculate_ng(custom_encut=2000) == (
+            [56, 96, 96],
+            [112, 192, 192],
+        )
 
         assert static_set.calculate_ng() == ([30, 48, 50], [60, 96, 100])
         # test `custom_prec` kwarg for final structure in above test using "NORMAL".
-        assert static_set.calculate_ng(custom_prec="NORMAL") == ([24, 36, 40], [48, 72, 80])
+        assert static_set.calculate_ng(custom_prec="NORMAL") == (
+            [24, 36, 40],
+            [48, 72, 80],
+        )
 
 
 class TestMatPESStaticSet(PymatgenTest):
@@ -917,7 +969,8 @@ class TestMatPESStaticSet(PymatgenTest):
     def test_functionals(self):
         xc_functional = "LDA"
         with pytest.raises(
-            ValueError, match=f"Unrecognized {xc_functional=}. Supported exchange-correlation functionals are "
+            ValueError,
+            match=f"Unrecognized {xc_functional=}. Supported exchange-correlation functionals are ",
         ):
             MatPESStaticSet(self.struct, xc_functional=xc_functional)
 
@@ -1272,7 +1325,10 @@ class TestMITNEBSet(PymatgenTest):
         vis = MITNEBSet(self.structures, unset_encut=True)
         assert "ENCUT" not in vis.incar
         n_structs = 2
-        with pytest.raises(ValueError, match=f"You need at least 3 structures for an NEB, got {n_structs}"):
+        with pytest.raises(
+            ValueError,
+            match=f"You need at least 3 structures for an NEB, got {n_structs}",
+        ):
             _ = MITNEBSet(self.structures[:n_structs], unset_encut=True)
 
     def test_incar(self):
@@ -1451,7 +1507,8 @@ class TestMVLGWSet(PymatgenTest):
         assert self.set.mode == "STATIC"
         mode = "EVGW"
         with pytest.raises(
-            ValueError, match=f"Invalid {mode=}, supported modes are {', '.join(map(repr, MVLGWSet.SUPPORTED_MODES))}"
+            ValueError,
+            match=f"Invalid {mode=}, supported modes are {', '.join(map(repr, MVLGWSet.SUPPORTED_MODES))}",
         ):
             _ = self.set(mode=mode)
         mvlgwsc = self.set(self.struct)
@@ -1519,6 +1576,73 @@ class TestMVLGWSet(PymatgenTest):
         assert mvlgwgbse1.incar["ALGO"] == "Bse"
 
 
+class TestMPHSERelaxSet(PymatgenTest):
+    def setUp(self):
+        self.structure = dummy_structure
+        self.set = MPHSERelaxSet
+
+    def test_vdw_and_lasph_none(self):
+        vis = self.set(self.structure, vdw=None)
+        assert vis.incar["LASPH"], "LASPH is not set to True"
+        vdw_keys = {"VDW_SR", "VDW_S8", "VDW_A1", "VDW_A2"}
+        assert all(key not in vis.incar for key in vdw_keys), "Unexpected vdW parameters are set"
+
+    def test_vdw_and_lasph_dftd3(self):
+        vis = self.set(self.structure, vdw="dftd3")
+        assert vis.incar["LASPH"], "LASPH is not set to True"
+        assert vis.incar["VDW_SR"] == pytest.approx(1.129), "VDW_SR is not set correctly"
+        assert vis.incar["VDW_S8"] == pytest.approx(0.109), "VDW_S8 is not set correctly"
+
+    def test_vdw_and_lasph_dftd3_bj(self):
+        vis = self.set(self.structure, vdw="dftd3-bj")
+        assert vis.incar["LASPH"], "LASPH is not set to True"
+        assert vis.incar["VDW_A1"] == pytest.approx(0.383), "VDW_A1 is not set correctly"
+        assert vis.incar["VDW_S8"] == pytest.approx(2.310), "VDW_S8 is not set correctly"
+        assert vis.incar["VDW_A2"] == pytest.approx(5.685), "VDW_A2 is not set correctly"
+
+    def test_user_incar_settings(self):
+        user_incar_settings = {"LASPH": False, "VDW_SR": 1.5}
+        vis = self.set(self.structure, vdw="dftd3", user_incar_settings=user_incar_settings)
+        assert not vis.incar["LASPH"], "LASPH user setting not applied"
+        assert vis.incar["VDW_SR"] == 1.5, "VDW_SR user setting not applied"
+
+    @unittest.skipIf(not os.path.exists(TEST_DIR), "Test files are not present.")
+    def test_from_prev_calc(self):
+        prev_run = os.path.join(TEST_DIR, "fixtures", "relaxation")
+
+        # Test for dftd3
+        vis_d3 = self.set.from_prev_calc(prev_calc_dir=prev_run, vdw="dftd3")
+        assert vis_d3.incar["LASPH"]
+        assert "VDW_SR" in vis_d3.incar
+        assert "VDW_S8" in vis_d3.incar
+
+        # Test for dftd3-bj
+        vis_bj = self.set.from_prev_calc(prev_calc_dir=prev_run, vdw="dftd3-bj")
+        assert vis_bj.incar["LASPH"]
+        assert "VDW_A1" in vis_bj.incar
+        assert "VDW_A2" in vis_bj.incar
+        assert "VDW_S8" in vis_bj.incar
+
+    @unittest.skipIf(not os.path.exists(TEST_DIR), "Test files are not present.")
+    def test_override_from_prev_calc(self):
+        prev_run = os.path.join(TEST_DIR, "fixtures", "relaxation")
+
+        # Test for dftd3
+        vis_d3 = self.set(self.structure, vdw="dftd3")
+        vis_d3 = vis_d3.override_from_prev_calc(prev_calc_dir=prev_run)
+        assert vis_d3.incar["LASPH"]
+        assert "VDW_SR" in vis_d3.incar
+        assert "VDW_S8" in vis_d3.incar
+
+        # Test for dftd3-bj
+        vis_bj = self.set(self.structure, vdw="dftd3-bj")
+        vis_bj = vis_bj.override_from_prev_calc(prev_calc_dir=prev_run)
+        assert vis_bj.incar["LASPH"]
+        assert "VDW_A1" in vis_bj.incar
+        assert "VDW_A2" in vis_bj.incar
+        assert "VDW_S8" in vis_bj.incar
+
+
 class TestMPHSEBS(PymatgenTest):
     def setUp(self):
         self.set = MPHSEBSSet
@@ -1580,7 +1704,11 @@ class TestMVLScanRelaxSet(PymatgenTest):
         self.set = MVLScanRelaxSet
         file_path = f"{VASP_IN_DIR}/POSCAR"
         self.struct = Structure.from_file(file_path)
-        self.mvl_scan_set = self.set(self.struct, user_potcar_functional="PBE_54", user_incar_settings={"NSW": 500})
+        self.mvl_scan_set = self.set(
+            self.struct,
+            user_potcar_functional="PBE_54",
+            user_incar_settings={"NSW": 500},
+        )
 
     def test_incar(self):
         incar = self.mvl_scan_set.incar
@@ -1603,35 +1731,43 @@ class TestMVLScanRelaxSet(PymatgenTest):
         assert input_set.potcar.functional == "PBE_52"
 
         with pytest.raises(
-            ValueError, match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54'\)"
+            ValueError,
+            match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54', 'PBE_64'\)",
         ):
             MVLScanRelaxSet(self.struct, user_potcar_functional="PBE")
 
-    # @skip_if_no_psp_dir
-    # def test_potcar(self):
-    #
-    #     test_potcar_set_1 = self.set(self.struct, user_potcar_functional="PBE_54")
-    #     assert test_potcar_set_1.potcar.functional == "PBE_54"
-    #
-    #     with pytest.raises(
-    #         ValueError, match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54'\)"
-    #     ):
-    #         self.set(self.struct, user_potcar_functional="PBE")
-    #
-    #     # https://github.com/materialsproject/pymatgen/pull/3022
-    #     # same test also in MITMPRelaxSetTest above (for redundancy,
-    #     # should apply to all classes inheriting from VaspInputSet)
-    #     for user_potcar_settings in [{"Fe": "Fe_pv"}, {"W": "W_pv"}, None]:
-    #         for species in [("W", "W"), ("Fe", "W"), ("Fe", "Fe")]:
-    #             struct = Structure(lattice=Lattice.cubic(3), species=species, coords=[[0, 0, 0], [0.5, 0.5, 0.5]])
-    #             relax_set = MPRelaxSet(
-    #                 structure=struct, user_potcar_functional="PBE_54", user_potcar_settings=user_potcar_settings
-    #             )
-    #             expected = {
-    #                 **({"W": "W_sv"} if "W" in struct.symbol_set else {}),
-    #                 **(user_potcar_settings or {}),
-    #             } or None
-    #             assert relax_set.user_potcar_settings == expected
+    @pytest.mark.skip("TODO: need someone to fix this")
+    @skip_if_no_psp_dir
+    def test_potcar_need_fix(self):
+        test_potcar_set_1 = self.set(self.struct, user_potcar_functional="PBE_54")
+        assert test_potcar_set_1.potcar.functional == "PBE_54"
+
+        with pytest.raises(
+            ValueError,
+            match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54', 'PBE_64'\)",
+        ):
+            self.set(self.struct, user_potcar_functional="PBE")
+
+        # https://github.com/materialsproject/pymatgen/pull/3022
+        # same test also in MITMPRelaxSetTest above (for redundancy,
+        # should apply to all classes inheriting from VaspInputSet)
+        for user_potcar_settings in [{"Fe": "Fe_pv"}, {"W": "W_pv"}, None]:
+            for species in [("W", "W"), ("Fe", "W"), ("Fe", "Fe")]:
+                struct = Structure(
+                    lattice=Lattice.cubic(3),
+                    species=species,
+                    coords=[[0, 0, 0], [0.5, 0.5, 0.5]],
+                )
+                relax_set = MPRelaxSet(
+                    structure=struct,
+                    user_potcar_functional="PBE_54",
+                    user_potcar_settings=user_potcar_settings,
+                )
+                expected = {
+                    **({"W": "W_sv"} if "W" in struct.symbol_set else {}),
+                    **(user_potcar_settings or {}),
+                }
+                assert relax_set.user_potcar_settings == expected
 
     def test_as_from_dict(self):
         dct = self.mvl_scan_set.as_dict()
@@ -1646,7 +1782,9 @@ class TestMPScanRelaxSet(PymatgenTest):
         file_path = f"{VASP_IN_DIR}/POSCAR"
         self.struct = Structure.from_file(file_path)
         self.mp_scan_set = MPScanRelaxSet(
-            self.struct, user_potcar_functional="PBE_52", user_incar_settings={"NSW": 500}
+            self.struct,
+            user_potcar_functional="PBE_52",
+            user_incar_settings={"NSW": 500},
         )
 
     def test_incar(self):
@@ -1692,7 +1830,13 @@ class TestMPScanRelaxSet(PymatgenTest):
         # Test that KSPACING is capped at 0.44 for insulators
         file_path = f"{VASP_IN_DIR}/POSCAR_O2"
         struct = Structure.from_file(file_path)
-        for bandgap, expected in ((10, 0.44), (3, 0.4136617), (1.1, 0.3064757), (0.5, 0.2832948), (0, 0.22)):
+        for bandgap, expected in (
+            (10, 0.44),
+            (3, 0.4136617),
+            (1.1, 0.3064757),
+            (0.5, 0.2832948),
+            (0, 0.22),
+        ):
             incar = MPScanRelaxSet(struct, bandgap=bandgap).incar
             assert incar["KSPACING"] == approx(expected, abs=1e-5)
             assert incar["ISMEAR"] == -5 if bandgap > 1e-4 else 2
@@ -1733,7 +1877,8 @@ class TestMPScanRelaxSet(PymatgenTest):
         assert input_set.potcar.functional == "PBE_54"
 
         with pytest.raises(
-            ValueError, match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54'\)"
+            ValueError,
+            match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54', 'PBE_64'\)",
         ):
             MPScanRelaxSet(self.struct, user_potcar_functional="PBE")
 
@@ -1886,7 +2031,11 @@ class TestMVLRelax52Set(PymatgenTest):
         self.set = MVLRelax52Set
         file_path = f"{VASP_IN_DIR}/POSCAR"
         self.struct = Structure.from_file(file_path)
-        self.mvl_rlx_set = self.set(self.struct, user_potcar_functional="PBE_54", user_incar_settings={"NSW": 500})
+        self.mvl_rlx_set = self.set(
+            self.struct,
+            user_potcar_functional="PBE_54",
+            user_incar_settings={"NSW": 500},
+        )
 
     def test_incar(self):
         incar = self.mvl_rlx_set.incar
@@ -1903,7 +2052,8 @@ class TestMVLRelax52Set(PymatgenTest):
         assert test_potcar_set_1.potcar.functional == "PBE_52"
 
         with pytest.raises(
-            ValueError, match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54'\)"
+            ValueError,
+            match=r"Invalid user_potcar_functional='PBE', must be one of \('PBE_52', 'PBE_54', 'PBE_64'\)",
         ):
             self.set(self.struct, user_potcar_functional="PBE")
 
@@ -1926,7 +2076,10 @@ class TestLobsterSet(PymatgenTest):
         self.lobsterset1 = self.set(self.struct, isym=-1, ismear=-5)
         self.lobsterset2 = self.set(self.struct, isym=0, ismear=0)
         # only allow isym=-1 and isym=0
-        with pytest.raises(ValueError, match="Lobster cannot digest WAVEFUNCTIONS with symmetry. isym must be -1 or 0"):
+        with pytest.raises(
+            ValueError,
+            match="Lobster cannot digest WAVEFUNCTIONS with symmetry. isym must be -1 or 0",
+        ):
             self.lobsterset_new = self.set(self.struct, isym=2, ismear=0)
         with pytest.raises(ValueError, match="Lobster usually works with ismear=-5 or ismear=0"):
             self.lobsterset_new = self.set(self.struct, isym=-1, ismear=2)
@@ -1986,7 +2139,8 @@ class TestLobsterSet(PymatgenTest):
         assert self.lobsterset2.potcar.symbols == ["Fe_pv", "P", "O"]
         # test if error raised contains correct potcar symbol for K element as PBE_54 set
         with pytest.raises(
-            FileNotFoundError, match=f"You do not have the right POTCAR with {functional=} and {symbol=}"
+            FileNotFoundError,
+            match=f"You do not have the right POTCAR with {functional=} and {symbol=}",
         ):
             _ = self.lobsterset9.potcar.symbols
 
@@ -2020,7 +2174,10 @@ class TestMPAbsorptionSet(PymatgenTest):
     def test_ipa(self):
         prev_run = f"{TEST_DIR}/fixtures/absorption/static"
         absorption_ipa = MPAbsorptionSet.from_prev_calc(
-            prev_calc_dir=prev_run, user_incar_settings={"NEDOS": 3000}, copy_wavecar=True, mode="IPA"
+            prev_calc_dir=prev_run,
+            user_incar_settings={"NEDOS": 3000},
+            copy_wavecar=True,
+            mode="IPA",
         )
         absorption_ipa.write_input(self.tmp_path)
         assert absorption_ipa.inherit_incar is True
@@ -2122,7 +2279,8 @@ def test_vasp_input_set_alias():
 
 def test_dict_set_alias():
     with pytest.warns(
-        FutureWarning, match="DictSet is deprecated, and will be removed on 2025-12-31\nUse VaspInputSet"
+        FutureWarning,
+        match="DictSet is deprecated, and will be removed on 2025-12-31\nUse VaspInputSet",
     ):
         DictSet()
     assert isinstance(DictSet(), VaspInputSet)
