@@ -1,7 +1,9 @@
 from __future__ import annotations
 
 import matplotlib.pyplot as plt
+import numpy as np
 import pytest
+from matplotlib import colors
 from pytest import approx
 
 from pymatgen.io.phonopy import get_gruneisen_ph_bs_symm_line, get_gruneisenparameter
@@ -32,6 +34,39 @@ class TestGruneisenPhononBandStructureSymmLine(PymatgenTest):
         ax = plotter.get_plot_gs()
         assert isinstance(ax, plt.Axes)
 
+    def test_ph_plot_w_gruneisen(self):
+        plotter = GruneisenPhononBSPlotter(bs=self.bs_symm_line)
+        ax = plotter.get_plot_gs(plot_ph_bs_with_gruneisen=True, units="THz", cmap=["red", "royalblue"])
+        assert ax.get_ylabel() == "Frequencies (THz)"
+        assert ax.get_xlabel() == "$\\mathrm{Wave\\ Vector}$"
+        assert ax.get_figure()._localaxes[-1].get_ylabel() == "$\\gamma \\ \\mathrm{(logarithmized)}$"
+        assert len(ax._children) == plotter.n_bands + 1  # check for number of bands
+        # check for x and y data is really the band-structure data
+        for inx, band in enumerate(plotter._bs.bands):
+            xy_data = {
+                "x": [point[0] for point in ax._children[inx].get_offsets().data],
+                "y": [point[1] for point in ax._children[inx].get_offsets().data],
+            }
+            assert band == pytest.approx(xy_data["y"])
+            assert plotter._bs.distance == pytest.approx(xy_data["x"])
+
+        # check if color bar max value matches maximum gruneisen parameter value
+        data = plotter.bs_plot_data()
+
+        # get reference min and max Grüneisen parameter values
+        max_gruneisen = np.array(data["gruneisen"]).max()
+        min_gruneisen = np.array(data["gruneisen"]).min()
+
+        norm = colors.SymLogNorm(
+            vmin=min_gruneisen,
+            vmax=max_gruneisen,
+            linthresh=1e-2,
+            linscale=1,
+        )
+
+        assert max(norm.inverse(ax.get_figure()._localaxes[-1].get_yticks())) == pytest.approx(max_gruneisen)
+        assert isinstance(ax, plt.Axes)
+
     def test_as_dict_from_dict(self):
         new_dict = self.bs_symm_line.as_dict()
         self.new_bs_symm_line = GruneisenPhononBandStructureSymmLine.from_dict(new_dict)
@@ -79,8 +114,8 @@ class TestGruneisenParameter(PymatgenTest):
         assert self.gruneisen_obj_small.gruneisen[5] == approx(1.7574050911)
 
     def test_tdos(self):
-        tdos = self.gruneisen_obj.tdos
-        assert isinstance(tdos, phonopy.phonon.dos.TotalDos)
+        tot_dos = self.gruneisen_obj.tdos
+        assert isinstance(tot_dos, phonopy.phonon.dos.TotalDos)
 
     def test_phdos(self):
         assert self.gruneisen_obj.phdos.cv(298.15) == approx(45.17772584681599)
