@@ -47,11 +47,6 @@ try:
 except ImportError:
     hiphive = None
 
-try:
-    import matgl
-except ImportError:
-    matgl = None
-
 
 def get_table():
     """Loads a lightweight lambda table for use in unit tests to reduce
@@ -72,7 +67,10 @@ enumlib_present = enum_cmd and makestr_cmd
 class TestSuperTransformation:
     def test_apply_transformation(self):
         trafo = SuperTransformation(
-            [SubstitutionTransformation({"Li+": "Na+"}), SubstitutionTransformation({"Li+": "K+"})]
+            [
+                SubstitutionTransformation({"Li+": "Na+"}),
+                SubstitutionTransformation({"Li+": "K+"}),
+            ]
         )
         coords = [
             [0, 0, 0],
@@ -187,7 +185,6 @@ class TestEnumerateStructureTransformation:
         for struct_trafo in alls:
             assert "energy" not in struct_trafo
 
-    @pytest.mark.skip("TODO remove skip once https://github.com/materialsvirtuallab/matgl/issues/238 is resolved")
     def test_m3gnet(self):
         pytest.importorskip("matgl")
         enum_trans = EnumerateStructureTransformation(refine_structure=True, sort_criteria="m3gnet_relax")
@@ -203,7 +200,6 @@ class TestEnumerateStructureTransformation:
         # Check ordering of energy/atom
         assert alls[0]["energy"] / alls[0]["num_sites"] <= alls[-1]["energy"] / alls[-1]["num_sites"]
 
-    @pytest.mark.skip("TODO remove skip once https://github.com/materialsvirtuallab/matgl/issues/238 is resolved")
     def test_callable_sort_criteria(self):
         matgl = pytest.importorskip("matgl")
         from matgl.ext.ase import Relaxer
@@ -601,7 +597,7 @@ class TestDisorderedOrderedTransformation(PymatgenTest):
 @pytest.mark.skipif(not mcsqs_cmd, reason="mcsqs not present.")
 class TestSQSTransformation(PymatgenTest):
     def test_apply_transformation(self):
-        pzt_structs = loadfn(f"{TEST_FILES_DIR}/mcsqs/pzt-structs.json")
+        pzt_structs = loadfn(f"{TEST_FILES_DIR}/io/atat/mcsqs/pzt-structs.json")
         trans = SQSTransformation(scaling=[2, 1, 1], search_time=0.01, instances=1, wd=0)
         # nonsensical example just for testing purposes
         struct = self.get_structure("Pb2TiZrO6").copy()
@@ -612,7 +608,7 @@ class TestSQSTransformation(PymatgenTest):
 
     def test_return_ranked_list(self):
         # list of structures
-        pzt_structs_2 = loadfn(f"{TEST_FILES_DIR}/mcsqs/pzt-structs-2.json")
+        pzt_structs_2 = loadfn(f"{TEST_FILES_DIR}/io/atat/mcsqs/pzt-structs-2.json")
 
         n_structs_expected = 1
         sqs_kwargs = {"scaling": 2, "search_time": 0.01, "instances": 8, "wd": 0}
@@ -676,7 +672,10 @@ class TestSQSTransformationIcet(PymatgenTest):
 
     def test_monte_carlo(self):
         sqs = SQSTransformation(
-            scaling=self.scaling, sqs_method="icet-monte_carlo", icet_sqs_kwargs={"n_steps": 5}, instances=2
+            scaling=self.scaling,
+            sqs_method="icet-monte_carlo",
+            icet_sqs_kwargs={"n_steps": 5},
+            instances=2,
         )
         sqs_structure = sqs.apply_transformation(self.stored_run["disordered_structure"], return_ranked_list=False)
         assert isinstance(sqs_structure, Structure)
@@ -693,7 +692,7 @@ class TestSQSTransformationIcet(PymatgenTest):
 
 
 class TestCubicSupercellTransformation(PymatgenTest):
-    def test_apply_transformation(self):
+    def test_apply_transformation_cubic_supercell(self):
         structure = self.get_structure("TlBiSe2")
         min_atoms = 100
         max_atoms = 1000
@@ -752,11 +751,94 @@ class TestCubicSupercellTransformation(PymatgenTest):
 
         # Test the transformation without constraining trans_mat to be diagonal
         supercell_generator = CubicSupercellTransformation(
-            min_atoms=min_atoms, max_atoms=max_atoms, min_length=10.0, force_90_degrees=True
+            min_atoms=min_atoms,
+            max_atoms=max_atoms,
+            min_length=10.0,
+            force_90_degrees=True,
         )
         transformed_structure = supercell_generator.apply_transformation(structure)
         assert_allclose(list(transformed_structure.lattice.angles), [90.0, 90.0, 90.0])
 
+    def test_apply_transformation_orthorhombic_supercell(self):
+        structure = self.get_structure("Li3V2(PO4)3")
+        min_atoms = 100
+        max_atoms = 400
+
+        supercell_generator_cubic = CubicSupercellTransformation(
+            min_atoms=min_atoms,
+            max_atoms=max_atoms,
+            min_length=10.0,
+            force_90_degrees=False,
+            allow_orthorhombic=False,
+            max_length=25,
+        )
+
+        transformed_cubic = supercell_generator_cubic.apply_transformation(structure)
+
+        supercell_generator_orthorhombic = CubicSupercellTransformation(
+            min_atoms=min_atoms,
+            max_atoms=max_atoms,
+            min_length=10.0,
+            force_90_degrees=False,
+            allow_orthorhombic=True,
+            max_length=25,
+        )
+
+        transformed_orthorhombic = supercell_generator_orthorhombic.apply_transformation(structure)
+
+        assert_array_equal(
+            supercell_generator_orthorhombic.transformation_matrix,
+            np.array([[0, -2, 1], [-2, 0, 0], [0, 0, -2]]),
+        )
+
+        # make sure that the orthorhombic supercell is different from the cubic cell
+        assert not np.array_equal(
+            supercell_generator_cubic.transformation_matrix,
+            supercell_generator_orthorhombic.transformation_matrix,
+        )
+        assert transformed_cubic.lattice.angles != transformed_orthorhombic.lattice.angles
+        assert transformed_orthorhombic.lattice.abc != transformed_cubic.lattice.abc
+
+        structure = self.get_structure("Si")
+        min_atoms = 100
+        max_atoms = 400
+
+        supercell_generator_cubic = CubicSupercellTransformation(
+            min_atoms=min_atoms,
+            max_atoms=max_atoms,
+            min_length=10.0,
+            force_90_degrees=True,
+            allow_orthorhombic=False,
+            max_length=25,
+        )
+
+        transformed_cubic = supercell_generator_cubic.apply_transformation(structure)
+
+        supercell_generator_orthorhombic = CubicSupercellTransformation(
+            min_atoms=min_atoms,
+            max_atoms=max_atoms,
+            min_length=10.0,
+            force_90_degrees=True,
+            allow_orthorhombic=True,
+            max_length=25,
+        )
+
+        transformed_orthorhombic = supercell_generator_orthorhombic.apply_transformation(structure)
+
+        assert_array_equal(
+            supercell_generator_orthorhombic.transformation_matrix,
+            np.array([[3, 0, 0], [-2, 4, 0], [-2, 4, 6]]),
+        )
+
+        # make sure that the orthorhombic supercell is different from the cubic cell
+        assert not np.array_equal(
+            supercell_generator_cubic.transformation_matrix,
+            supercell_generator_orthorhombic.transformation_matrix,
+        )
+        assert transformed_orthorhombic.lattice.abc != transformed_cubic.lattice.abc
+        # only angels are expected to be the same because of force_90_degrees = True
+        assert transformed_cubic.lattice.angles == transformed_orthorhombic.lattice.angles
+
 
 class TestAddAdsorbateTransformation(PymatgenTest):
     def test_apply_transformation(self):
