@@ -123,7 +123,7 @@ class TestSupercellTransformation(TestCase):
         assert struct.formula == "Li16 O16"
 
     def test_from_scaling_factors(self):
-        scale_factors = np.random.randint(1, 5, 3)
+        scale_factors = np.random.default_rng().integers(1, 5, 3)
         trafo = SupercellTransformation.from_scaling_factors(*scale_factors)
         struct = trafo.apply_transformation(self.struct)
         assert len(struct) == 4 * functools.reduce(operator.mul, scale_factors)
@@ -180,7 +180,10 @@ class TestOxidationStateDecorationTransformation:
         assert struct_trafo[0].species_string == "Li+"
         assert struct_trafo[2].species_string == "O2-"
         dct = trafo.as_dict()
-        assert isinstance(OxidationStateDecorationTransformation.from_dict(dct), OxidationStateDecorationTransformation)
+        assert isinstance(
+            OxidationStateDecorationTransformation.from_dict(dct),
+            OxidationStateDecorationTransformation,
+        )
 
 
 class TestAutoOxiStateDecorationTransformation:
@@ -213,7 +216,10 @@ class TestOxidationStateRemovalTransformation:
         assert struct_trafo[2].species_string == "O"
 
         dct = trafo.as_dict()
-        assert isinstance(OxidationStateRemovalTransformation.from_dict(dct), OxidationStateRemovalTransformation)
+        assert isinstance(
+            OxidationStateRemovalTransformation.from_dict(dct),
+            OxidationStateRemovalTransformation,
+        )
 
 
 @pytest.mark.skipif(not enumlib_present, reason="enum_lib not present.")
@@ -230,11 +236,21 @@ class TestPartialRemoveSpecieTransformation:
         assert len(trafo.apply_transformation(struct, 100)) == 2
 
         dct = trafo.as_dict()
-        assert isinstance(PartialRemoveSpecieTransformation.from_dict(dct), PartialRemoveSpecieTransformation)
+        assert isinstance(
+            PartialRemoveSpecieTransformation.from_dict(dct),
+            PartialRemoveSpecieTransformation,
+        )
 
     def test_apply_transformation_fast(self):
         trafo = PartialRemoveSpecieTransformation("Li+", 0.5)
-        coords = [[0, 0, 0], [0.75, 0.75, 0.75], [0.5, 0.5, 0.5], [0.25, 0.25, 0.25], [0.1, 0.1, 0.1], [0.3, 0.75, 0.3]]
+        coords = [
+            [0, 0, 0],
+            [0.75, 0.75, 0.75],
+            [0.5, 0.5, 0.5],
+            [0.25, 0.25, 0.25],
+            [0.1, 0.1, 0.1],
+            [0.3, 0.75, 0.3],
+        ]
         lattice = Lattice([[10, 0, 0], [0, 10, 0], [0, 0, 10]])
         struct = Structure(lattice, ["Li+"] * 6, coords)
         fast_opt_s = trafo.apply_transformation(struct)
@@ -304,7 +320,10 @@ class TestOrderDisorderedStructureTransformation:
         assert len(all_structs) == 3
 
         dct = trafo.as_dict()
-        assert isinstance(OrderDisorderedStructureTransformation.from_dict(dct), OrderDisorderedStructureTransformation)
+        assert isinstance(
+            OrderDisorderedStructureTransformation.from_dict(dct),
+            OrderDisorderedStructureTransformation,
+        )
 
     def test_no_oxidation(self):
         specie = {"Cu1+": 0.5, "Au2+": 0.5}
@@ -320,7 +339,13 @@ class TestOrderDisorderedStructureTransformation:
     def test_symmetrized_structure(self):
         trafo = OrderDisorderedStructureTransformation(symmetrized_structures=True)
         lattice = Lattice.cubic(5)
-        coords = [[0.5, 0.5, 0.5], [0.45, 0.45, 0.45], [0.56, 0.56, 0.56], [0.25, 0.75, 0.75], [0.75, 0.25, 0.25]]
+        coords = [
+            [0.5, 0.5, 0.5],
+            [0.45, 0.45, 0.45],
+            [0.56, 0.56, 0.56],
+            [0.25, 0.75, 0.75],
+            [0.75, 0.25, 0.25],
+        ]
         struct = Structure(lattice, [{"Si4+": 1}, *[{"Si4+": 0.5}] * 4], coords)
         test_site = PeriodicSite("Si4+", coords[2], lattice)
         struct = SymmetrizedStructure(struct, "not_real", [0, 1, 1, 2, 2], ["a", "b", "b", "c", "c"])
@@ -330,9 +355,18 @@ class TestOrderDisorderedStructureTransformation:
     def test_too_small_cell(self):
         trafo = OrderDisorderedStructureTransformation()
         coords = [[0.5, 0.5, 0.5]]
-        lattice = Lattice([[3.8401979337, 0, 0], [1.9200989668, 3.3257101909, 0], [0, -2.2171384943, 3.1355090603]])
+        lattice = Lattice(
+            [
+                [3.8401979337, 0, 0],
+                [1.9200989668, 3.3257101909, 0],
+                [0, -2.2171384943, 3.1355090603],
+            ]
+        )
         struct = Structure(lattice, [{"X4+": 0.33, "O2-": 0.33, "P5+": 0.33}], coords)
-        with pytest.raises(ValueError, match="Occupancy fractions not consistent with size of unit cell"):
+        with pytest.raises(
+            ValueError,
+            match="Occupancy fractions not consistent with size of unit cell",
+        ):
             trafo.apply_transformation(struct)
 
     def test_best_first(self):
@@ -429,7 +463,10 @@ class TestPerturbStructureTransformation:
             assert site.distance(struct[idx]) == approx(0.05)
 
         dct = trafo.as_dict()
-        assert isinstance(PerturbStructureTransformation.from_dict(dct), PerturbStructureTransformation)
+        assert isinstance(
+            PerturbStructureTransformation.from_dict(dct),
+            PerturbStructureTransformation,
+        )
 
         t2 = PerturbStructureTransformation(0.05, 0)
         transformed_s2 = t2.apply_transformation(struct)
@@ -438,7 +475,10 @@ class TestPerturbStructureTransformation:
             assert site.distance(struct[idx]) >= 0
 
         dct = t2.as_dict()
-        assert isinstance(PerturbStructureTransformation.from_dict(dct), PerturbStructureTransformation)
+        assert isinstance(
+            PerturbStructureTransformation.from_dict(dct),
+            PerturbStructureTransformation,
+        )
 
 
 class TestDeformStructureTransformation:
@@ -480,7 +520,11 @@ class TestDiscretizeOccupanciesTransformation:
         )
         dot = DiscretizeOccupanciesTransformation(max_denominator=5, tol=0.5)
         struct = dot.apply_transformation(struct_orig)
-        assert dict(struct[0].species) == {Element("Li"): 0.2, Element("Na"): 0.2, Element("K"): 0.6}
+        assert dict(struct[0].species) == {
+            Element("Li"): 0.2,
+            Element("Na"): 0.2,
+            Element("K"): 0.6,
+        }
 
         dot = DiscretizeOccupanciesTransformation(max_denominator=5, tol=0.01)
         with pytest.raises(RuntimeError, match="Cannot discretize structure within tolerance!"):
